##  Attributes
The Edit pane displays fact sheet data and its attributes based on the View and Settings of the report. For instance, if you select Business Criticality View, then in the application landscape report, the business criticality field will be available to edit in the Edit pane.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750a3de7a441014b4f59163a4e7267e_LowRes.png)
You can also edit the left and right properties displayed on report items in the side pane. You can easily accomplish this by including them in the report properties from the Settings page. Once both fields are enabled, you'll be able to view and edit them in the Edit pane window.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fa9467a441014a5bea99acecd41df_LowRes.gif)
